==> unity-changeset-2.3.1.tgz: package/esm/unityGraphQL.js <==
import { UnityChangeset } from "./unityChangeset.js";
import { gql, GraphQLClient } from "graphql-request";
const UNITY_GRAPHQL_ENDPOINT = "https://services.unity.com/graphql";
export var UnityReleaseStream;
(function (UnityReleaseStream) {
    UnityReleaseStream["LTS"] = "LTS";
    UnityReleaseStream["TECH"] = "TECH";
    UnityReleaseStream["BETA"] = "BETA";
    UnityReleaseStream["ALPHA"] = "ALPHA";
})(UnityReleaseStream || (UnityReleaseStream = {}));
export async function getUnityReleases(version, stream = []) {
    const client = new GraphQLClient(UNITY_GRAPHQL_ENDPOINT);
    const query = gql `
query GetRelease($limit: Int, $skip: Int, $version: String!, $stream: [UnityReleaseStream!])
{
  getUnityReleases(
    limit: $limit
    skip: $skip
    stream: $stream
    version: $version
    entitlements: []
  ) {
    totalCount
    edges {
      node {
        version
        shortRevision
        stream
      }
    }
    pageInfo {
      hasNextPage
    }
  }
}
`;
    const variables = {
        limit: 1000,
        skip: 0,
        version: version,
        stream: stream,
    };
    const results = [];
    while (true) {
        const data = await client.request(query, variables);
        results.push(...data.getUnityReleases.edges.map((edge) => new UnityChangeset(edge.node.version, edge.node.shortRevision, edge.node.stream == UnityReleaseStream.LTS)));
        if (data.getUnityReleases.pageInfo.hasNextPage === false) {
            break;
        }
        variables.skip += variables.limit;
    }
    return results;
}
export async function getUnityReleasesInLTS() {
    const client = new GraphQLClient(UNITY_GRAPHQL_ENDPOINT);
    const query = gql `
query {
  getUnityReleaseMajorVersions(
    stream: []
    platform: []
    architecture: []
    entitlements: []
  ) {
    version
  }
}
`;
    const data = await client.request(query);
    const results = await Promise.all(data.getUnityReleaseMajorVersions
        .map(async (v) => {
        return await getUnityReleases(v.version, [UnityReleaseStream.LTS]);
    }));
    return results.flat();
}

==> unity-changeset-2.4.0.tgz: package/esm/unityGraphQL.js <==
import { UnityChangeset } from "./unityChangeset.js";
import { gql, GraphQLClient } from "graphql-request";
const UNITY_GRAPHQL_ENDPOINT = "https://services.unity.com/graphql";
export var UnityReleaseStream;
(function (UnityReleaseStream) {
    UnityReleaseStream["LTS"] = "LTS";
    UnityReleaseStream["TECH"] = "TECH";
    UnityReleaseStream["BETA"] = "BETA";
    UnityReleaseStream["ALPHA"] = "ALPHA";
})(UnityReleaseStream || (UnityReleaseStream = {}));
export var UnityReleaseEntitlement;
(function (UnityReleaseEntitlement) {
    UnityReleaseEntitlement["XLTS"] = "XLTS";
    UnityReleaseEntitlement["U7_ALPHA"] = "U7_ALPHA";
})(UnityReleaseEntitlement || (UnityReleaseEntitlement = {}));
export async function getUnityReleases(version, stream = [], entitlements = []) {
    const client = new GraphQLClient(UNITY_GRAPHQL_ENDPOINT);
    const query = gql `
query GetRelease($limit: Int, $skip: Int, $version: String!, $stream: [UnityReleaseStream!], $entitlements: [UnityReleaseEntitlement!])
{
  getUnityReleases(
    limit: $limit
    skip: $skip
    stream: $stream
    version: $version
    entitlements: $entitlements
  ) {
    totalCount
    edges {
      node {
        version
        shortRevision
        stream
      }
    }
    pageInfo {
      hasNextPage
    }
  }
}
`;
    const variables = {
        limit: 1000,
        skip: 0,
        version: version,
        stream: stream,
        entitlements: entitlements,
    };
    const results = [];
    while (true) {
        const data = await client.request(query, variables);
        results.push(...data.getUnityReleases.edges.map((edge) => new UnityChangeset(edge.node.version, edge.node.shortRevision, edge.node.stream == UnityReleaseStream.LTS)));
        if (data.getUnityReleases.pageInfo.hasNextPage === false) {
            break;
        }
        variables.skip += variables.limit;
    }
    return results;
}
export async function getUnityReleasesInLTS(entitlements = []) {
    const client = new GraphQLClient(UNITY_GRAPHQL_ENDPOINT);
    const query = gql `
query GetReleaseMajorVersions($entitlements: [UnityReleaseEntitlement!])
{
  getUnityReleaseMajorVersions(
    stream: []
    platform: []
    architecture: []
    entitlements: $entitlements
  ) {
    version
  }
}
`;
    const variables = {
        entitlements: entitlements,
    };
    const data = await client.request(query, variables);
    const results = await Promise.all(data.getUnityReleaseMajorVersions
        .map(async (v) => {
        return await getUnityReleases(v.version, [UnityReleaseStream.LTS], entitlements);
    }));
    return results.flat();
}
